@@ -64,7 +64,9 @@ class _ClientBase:
         # some other attribute creation
         self._last_ping = time()
 
-        self.parametres_utilisateur = self.auth_cookie = self.info = None
+        self.parametres_utilisateur: dict = {}
+        self.auth_cookie: dict = {}
+        self.info: Optional[dataClasses.ClientInfo] = None
 
         self.start_day = datetime.datetime.strptime(
             self.func_options['donneesSec']['donnees']['General']['PremierLundi']['V'], '%d/%m/%Y').date()
@@ -146,7 +148,9 @@ class _ClientBase:
             log.info('login failed')
             return False
 
-    def get_week(self, date: datetime.date):
+    def get_week(self, date: Union[datetime.date, datetime.datetime]):
+        if isinstance(date, datetime.datetime):
+            return 1 + int((date.date() - self.start_day).days / 7)
         return 1 + int((date - self.start_day).days / 7)
 
     @property
@@ -164,7 +168,6 @@ class _ClientBase:
         json = self.func_options['donneesSec']['donnees']['General']['ListePeriodes']
         return [dataClasses.Period(self, j) for j in json]
 
-
     def keep_alive(self):
         """
         Returns a context manager to keep the connection alive. When inside the context manager,
@@ -235,7 +238,7 @@ class _ClientBase:
             log.info(
                 f'Have you tried turning it off and on again? ERROR: {e.pronote_error_code} | {e.pronote_error_msg}')
             self.refresh()
-            return self.communication.post(function_name, data, True)
+            return self.communication.post(function_name, post_data)
 
 
 class Client(_ClientBase):
@@ -269,15 +272,18 @@ class Client(_ClientBase):
     def __init__(self, pronote_url, username: str = '', password: str = '', ent: Optional[Callable] = None):
         super().__init__(pronote_url, username, password, ent)
 
-    def lessons(self, date_from: datetime.date, date_to: datetime.date = None) -> List[dataClasses.Lesson]:
+    def lessons(self, date_from: Union[datetime.date, datetime.datetime],
+                date_to: Union[datetime.date, datetime.datetime] = None) -> List[dataClasses.Lesson]:
         """
         Gets all lessons in a given timespan.
 
         :rtype: List[dataClasses.Lesson]
         :returns: List of lessons
 
-        :param date_from: first date
-        :param date_to: second date
+        :param date_from: Union[datetime.date, datetime.datetime]
+            first date
+        :param date_to: Union[datetime.date, datetime.datetime]
+            second date
         """
         user = self.parametres_utilisateur['donneesSec']['donnees']['ressource']
         data = {"ressource": user,
@@ -287,9 +293,17 @@ class Client(_ClientBase):
                 "Ressource": user}
         output = []
 
-        first_week = self.get_week(date_from)
+        # convert date to datetime
+        if isinstance(date_from, datetime.date):
+            date_from = datetime.datetime.combine(date_from, datetime.datetime.min.time())
+
+        if isinstance(date_to, datetime.date):
+            date_to = datetime.datetime.combine(date_to, datetime.datetime.min.time())
+
         if not date_to:
-            date_to = date_from
+            date_to = datetime.datetime.combine(date_from, datetime.datetime.max.time())
+
+        first_week = self.get_week(date_from)
         last_week = self.get_week(date_to)
 
         # getting lessons for all the weeks.
@@ -301,7 +315,7 @@ class Client(_ClientBase):
                 output.append(dataClasses.Lesson(self, lesson))
 
         # since we only have week precision, we need to make it more precise on our own
-        return [lesson for lesson in output if date_from <= lesson.start.date() <= date_to]
+        return [lesson for lesson in output if date_from <= lesson.start <= date_to]
 
     def homework(self, date_from: datetime.date, date_to: datetime.date = None) -> List[dataClasses.Homework]:
         """
@@ -345,6 +359,40 @@ class Client(_ClientBase):
         return [dataClasses.Message(self, m) for m in messages['donneesSec']['donnees']['listeMessagerie']['V']
                 if not m.get('estUneDiscussion')]
 
+    def information_and_surveys(self, date_from: datetime.datetime = None, date_to: datetime.datetime = None,
+                                only_unread: bool = False, ) -> List[dataClasses.Information]:
+        """
+        Gets all the information and surveys in the information and surveys tab.
+
+        Parameters
+        ----------
+        only_unread : bool
+            Return only unread information
+        date_from : datetime.datetime
+            The first date
+        date_to : datetime.datetime
+            The second date
+
+        Returns
+        -------
+        List[Information]
+            Information
+        """
+        response = self.post('PageActualites', 8, {'estAuteur': False})
+        info = [dataClasses.Information(self, info) for info in
+                response['donneesSec']['donnees']['listeActualites']['V']]
+
+        if only_unread:
+            info = [i for i in info if not i.read]
+
+        if date_from is not None:
+            info = [i for i in info if i.start_date >= date_from]
+
+        if date_to is not None:
+            info = [i for i in info if i.start_date <= date_to]
+
+        return info
+
     @property
     def current_period(self) -> dataClasses.Period:
         """Get the current period."""
@@ -381,17 +429,18 @@ class ParentClient(Client):
         List of sub-clients representing all the children connected to the main parent account.
     """
 
-    def __init__(self, pronote_url, username: str = '', password: str = '', ent: Optional[Callable] = None,
-                 child: str = None):
+    def __init__(self, pronote_url, username: str = '', password: str = '', ent: Optional[Callable] = None):
         super().__init__(pronote_url, username, password, ent)
-        self.children = []
-        self._selected_child = None
+
+        self.children: List[dataClasses.ClientInfo] = []
         for c in self.parametres_utilisateur['donneesSec']['donnees']['ressource']['listeRessources']:
             self.children.append(dataClasses.ClientInfo(c))
 
         if not self.children:
             raise ChildNotFound('No children were found.')
-        self.set_child(child if child else self.children[0])
+
+        self._selected_child: dataClasses.ClientInfo = self.children[0]
+        self.parametres_utilisateur['donneesSec']['donnees']['ressource'] = self._selected_child.raw_resource
 
     def set_child(self, child: Union[str, dataClasses.ClientInfo]) -> None:
         """
@@ -403,8 +452,8 @@ class ParentClient(Client):
             Name or ClientInfo of a child.
         """
         if type(child) == str:
-            c = dataClasses.Util.get(self.children, name=child)
-            c = c[0] if c else None
+            candidates = dataClasses.Util.get(self.children, name=child)
+            c = candidates[0] if candidates else None
         else:
             c = child
 
@@ -412,7 +461,7 @@ class ParentClient(Client):
             raise ChildNotFound(f"A child with the name {child} was not found.")
 
         self._selected_child = c
-        self.parametres_utilisateur['donneesSec']['donnees']['ressource'] = c.raw_resource
+        self.parametres_utilisateur['donneesSec']['donnees']['ressource'] = self._selected_child.raw_resource
 
     def post(self, function_name: str, onglet: int = None, data: dict = None):
         """
@@ -444,7 +493,7 @@ class ParentClient(Client):
             log.info(
                 f'Have you tried turning it off and on again? ERROR: {e.pronote_error_code} | {e.pronote_error_msg}')
             self.refresh()
-            return self.communication.post(function_name, data, True)
+            return self.communication.post(function_name, post_data)
 
 
 class VieScolaireClient(_ClientBase):
