@@ -1,4 +1,5 @@
 import datetime
+import typing
 import unittest
 
 import pronotepy
@@ -45,6 +46,9 @@ class TestClient(unittest.TestCase):
 
 
 class TestPeriod(unittest.TestCase):
+
+    period: pronotepy.Period
+
     @classmethod
     def setUpClass(cls) -> None:
         global client
@@ -69,7 +73,34 @@ class TestPeriod(unittest.TestCase):
                 self.assertIsNotNone(acquisition)
 
 
+class TestInformation(unittest.TestCase):
+
+    def test_attribute_type(self):
+        information = client.information_and_surveys()
+        for info in information:
+            for attr_name, attr_type in typing.get_type_hints(pronotepy.Information).items():
+                with self.subTest(attr_name=attr_name, attr_type=attr_type):
+                    if isinstance(attr_type, typing._BaseGenericAlias):
+                        attr_type = typing.get_args(attr_type)
+                    self.assertIsInstance(info.__getattribute__(attr_name), attr_type)
+
+    def test_unread(self):
+        information = client.information_and_surveys(only_unread=True)
+        for info in information:
+            self.assertFalse(info.read)
+
+    def test_time_delta(self):
+        start = datetime.datetime(year=client.start_day.year, month=client.start_day.month, day=client.start_day.day)
+        end = start + datetime.timedelta(days=100)
+        information = client.information_and_surveys(date_from=start, date_to=end)
+        for info in information:
+            self.assertTrue(start <= info.start_date <= end, msg="date outside the research limits")
+
+
 class TestLesson(unittest.TestCase):
+
+    lesson: pronotepy.Lesson
+
     @classmethod
     def setUpClass(cls) -> None:
         global client
@@ -83,6 +114,9 @@ class TestLesson(unittest.TestCase):
 
 
 class TestLessonContent(unittest.TestCase):
+
+    lessonContent: pronotepy.LessonContent
+
     @classmethod
     def setUpClass(cls) -> None:
         global client
@@ -93,6 +127,9 @@ class TestLessonContent(unittest.TestCase):
 
 
 class TestParentClient(unittest.TestCase):
+
+    client: pronotepy.ParentClient
+
     @classmethod
     def setUpClass(cls) -> None:
         cls.client = pronotepy.ParentClient('https://demo.index-education.net/pronote/parent.html',
@@ -108,6 +145,9 @@ class TestParentClient(unittest.TestCase):
 
 
 class TestVieScolaireClient(unittest.TestCase):
+
+    client: pronotepy.VieScolaireClient
+
     @classmethod
     def setUpClass(cls) -> None:
         cls.client = pronotepy.VieScolaireClient('https://demo.index-education.net/pronote/viescolaire.html',
